<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Благодарности</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переводы</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Версия: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga это виртуальный принтер для CUPS. Программа можно  использовать для предпросмотра или для печати буклетов.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Авторские права: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Домашняя страница: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Лицензия: %1</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on Github.</source>
        <translation>Boomaga разрабатывается &lt;a %1&gt;командой Boomaga и помощниками &lt;/a&gt; на Github.</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Если есть желание работать вместе с нашей командой разработчиков - &lt;a %1&gt;присоединяйтесь&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Отдельное спасибо:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Если Вы хотите помочь с переводом, мы будем рады видеть вас в нашей команде переводчиков на  &lt;a %1&gt;Transifex server&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Разбивать большую книгу на небольшие тетрадки при печати.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Печатать с разбивкой на тетради </translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Максимальное число листов в тетради.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Листов в тетради:</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Сохранить как PDF файл</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Мета информация</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Автор:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Имя человека, создавшего документ.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message utf8="true">
        <source> The document’s title.</source>
        <translation>Заголовок документа.</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>Тема документа.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Ключевые слова, связанные с документом.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Ключевые слова:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>Файл PDF (*.pdf);;Все файлы (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Переписать файл?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Файл с именем &quot;%1&quot; уже существует.
Заменить его?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Заголовок документа.</translation>
    </message>
</context>
<context>
    <name>JobsListView</name>
    <message>
        <source>( %1 pages )</source>
        <translation>( %1 стр.) </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 страница на лист</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 страницы на лист</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Книгой</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Печатать на обеих сторонах листа</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>На обеих сторонах листа</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Задания</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Принтер</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Настроить...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>тулбар</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Печать</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Печать и выход</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v из %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Сейчас печатаются все страницы на %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Сейчас печатаются нечетные страницы на %1.&lt;p&gt;После окончания переверните страницы, вставьте их в принтер&lt;br&gt;и нажмите кнопку &quot;Продолжить&quot;.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Сейчас печатаются четные страницы на %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 страниц</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 страница</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 лист.</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 лист</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Лист %1 из %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Вставить пустую страницу после этой</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Удалить эту страницу</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Отмена удаления</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Вставить пустую страницу перед этой</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job.</source>
        <translation>Удалить страницы до конца задания. </translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Сохранить проект</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Сохранить проект под другим именем</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Открыть...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Открыть существующий проект</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Страница %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Бумажные файлы (*.boo);;Все файлы (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Проект сохранен.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Все поддерживаемые файлы (*.pdf *.boo);;Бумажные файлы (*.boo);;PDF документы (*.pdf);;Все файлы (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 стр. на лист горизонтально</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 стр. на лист вертикально</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 стр. на лист горизонтально</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 стр. на лист вертикально</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Начать новую тетрадь с этой страницы</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Не начинать новую тетрадь с этой страницы</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Повернуть страницу против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Повернуть страницу по часовой стрелке</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Переименовать задание</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Повернуть задание против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Повернуть задание по часовой стрелке</translation>
    </message>
    <message>
        <source>Delete job</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Имя задания:</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Экспортировать...</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Экспортировать проект в PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Клонировать задание...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Клонирование задания</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Количество копий</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Печать с выбором настроек...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Выбор количества копий перед печатью.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Печать документа</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Количество копий:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Поля (мм)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Правое:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Нижнее:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Внутренние:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Левое:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Верхнее:</translation>
    </message>
    <message>
        <source>Duplex:</source>
        <translation>Дуплекс</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Печатать рамку</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Печатать в обратном порядке</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Принтер умеет двухстороннюю печать</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Вручную с изменением порядка (большинство принтеров)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Вручную без изменениея порядка</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Настройки &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Профили</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Профиль %1</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation>Не получилось открыть файл: &quot;%1&quot; (Нет такого файла или директории)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation>Не получилось открыть файл: &quot;%1&quot; (Доступ запрещен)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; because is either not a supported file type or because the file has been damaged.</source>
        <translation>Не получилось прочитать файл: &quot;%1&quot;, файл испорчен или файлы такого типа не поддерживаются.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>PDF file &quot;%1&quot; is damaged.</source>
        <translation>Похоже, PDF файл &quot;%1&quot; нездоров.</translation>
    </message>
    <message>
        <source>PDF file &quot;%1&quot; is encripted.</source>
        <translation>Похоже, PDF файл &quot;%1&quot; зашифрован.</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Print to file (PDF)</source>
        <translation>Сохранить как PDF файл</translation>
    </message>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Не получилось прочитать файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без имени</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Безимянный.pdf</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Не получилось создать временный файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation>Шеф, все пропало! Я не могу найти программу с именем boomagamerger. Попробуй переставить меня.</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Не получилось прочитать файл: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
    </message>
</context>
</TS>